/*! @boldr/auth v0.1.0-alpha.2 by Steven Truesdell <steven@strues.io> */
/* eslint-disable */
const cache = {};

class Storage$1 {
  constructor(opts = {}) {
    Object.keys(Storage$1.defaults).map(key => {
      this[key] = opts.hasOwnProperty(key) ? opts[key] : Storage$1.defaults[key];
    });
  }
}

Storage$1.defaults = {
  // localStorage, sessionStorage or custom conforming to storage API
  storage: typeof window !== 'undefined' ? window.localStorage : null
};
/* istanbul ignore next */
Storage$1.create = opts => new Storage$1(opts);

Storage$1.cache = cache;

Storage$1.prototype.cache = cache;

Storage$1.prototype.get = function (key) {
  try {
    return this.storage.getItem(key);
  } catch (e) {
    return this.cache[key];
  }
};

Storage$1.prototype.set = function (key, value) {
  try {
    this.storage.setItem(key, value);
    /* istanbul ignore next */
    return value;
  } catch (e) {
    this.cache[key] = value;
    return value;
  }
};

Storage$1.prototype.remove = function (key) {
  try {
    this.storage.removeItem(key);
  } catch (e) {
    delete this.cache[key];
  }
};

var Storage$$1 = new Storage$1();

const TOKEN_KEY = 'bjwt';

const parseJWT = token => {
  if (!token) {
    /* istanbul ignore next */
    return null;
  }
  const base64Url = token;
  const base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');

  const parts = base64.split('.');
  if (parts.length !== 3) {
    /* istanbul ignore next */
    return null;
  }

  try {
    const [headerRaw, payloadRaw, signatureRaw] = parts;

    const header = JSON.parse(atob(headerRaw));
    const payload = JSON.parse(atob(payloadRaw));
    const signature = atob(signatureRaw);
    const issuedAt = payload.iat;
    const expiredToken = checkTokenExpiration(issuedAt);
    // If the token is expired, remove it.
    // this forces the user to login again.
    if (expiredToken === true) {
      /* istanbul ignore next */
      Storage$$1.remove(TOKEN_KEY);
      /* istanbul ignore next */
      return null;
    }
    return {
      header,
      payload,
      signature
    };
  } catch (err) {
    /* istanbul ignore next */
    console.error(err);
    /* istanbul ignore next */
    return null;
  }
};

function checkTokenExpiration(iat) {
  const date = new Date(0);
  const expirationDate = date.setUTCSeconds(iat);

  return expirationDate < new Date();
}

const setToken = token => {
  return Storage$$1.set(TOKEN_KEY, token);
};

const getToken = (asJSON = false) => {
  const token = Storage$$1.get(TOKEN_KEY);
  if (asJSON) {
    return parseJWT(token);
  }
  /* istanbul ignore next */
  return token;
};
/* istanbul ignore next */
function removeToken() {
  /* istanbul ignore next */
  Storage$$1.remove(TOKEN_KEY);
}

/* istanbul ignore next */

export { getToken, parseJWT, setToken, removeToken };
//# sourceMappingURL=boldr-auth.browser.es2015.esm.js.map
