/*! @boldr/auth v0.1.0-alpha.2 by Steven Truesdell <steven@strues.io> */
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';

/* eslint-disable */
var cache = {};

var Storage$1 = function Storage() {
  var _this = this;

  var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, Storage);

  Object.keys(Storage.defaults).map(function (key) {
    _this[key] = opts.hasOwnProperty(key) ? opts[key] : Storage.defaults[key];
  });
};

Storage$1.defaults = {
  // localStorage, sessionStorage or custom conforming to storage API
  storage: typeof window !== 'undefined' ? window.localStorage : null
};
/* istanbul ignore next */
Storage$1.create = function (opts) {
  return new Storage$1(opts);
};

Storage$1.cache = cache;

Storage$1.prototype.cache = cache;

Storage$1.prototype.get = function (key) {
  try {
    return this.storage.getItem(key);
  } catch (e) {
    return this.cache[key];
  }
};

Storage$1.prototype.set = function (key, value) {
  try {
    this.storage.setItem(key, value);
    /* istanbul ignore next */
    return value;
  } catch (e) {
    this.cache[key] = value;
    return value;
  }
};

Storage$1.prototype.remove = function (key) {
  try {
    this.storage.removeItem(key);
  } catch (e) {
    delete this.cache[key];
  }
};

var Storage = new Storage$1();

var TOKEN_KEY = 'bjwt';

var parseJWT = function parseJWT(token) {
  if (!token) {
    /* istanbul ignore next */
    return null;
  }
  var base64Url = token;
  var base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');

  var parts = base64.split('.');
  if (parts.length !== 3) {
    /* istanbul ignore next */
    return null;
  }

  try {
    var headerRaw = parts[0],
        payloadRaw = parts[1],
        signatureRaw = parts[2];


    var header = JSON.parse(atob(headerRaw));
    var payload = JSON.parse(atob(payloadRaw));
    var signature = atob(signatureRaw);
    var issuedAt = payload.iat;
    var expiredToken = checkTokenExpiration(issuedAt);
    // If the token is expired, remove it.
    // this forces the user to login again.
    if (expiredToken === true) {
      /* istanbul ignore next */
      Storage.remove(TOKEN_KEY);
      /* istanbul ignore next */
      return null;
    }
    return {
      header: header,
      payload: payload,
      signature: signature
    };
  } catch (err) {
    /* istanbul ignore next */
    console.error(err);
    /* istanbul ignore next */
    return null;
  }
};

function checkTokenExpiration(iat) {
  var date = new Date(0);
  var expirationDate = date.setUTCSeconds(iat);

  return expirationDate < new Date();
}

var setToken = function setToken(token) {
  return Storage.set(TOKEN_KEY, token);
};

var getToken = function getToken() {
  var asJSON = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;

  var token = Storage.get(TOKEN_KEY);
  if (asJSON) {
    return parseJWT(token);
  }
  /* istanbul ignore next */
  return token;
};
/* istanbul ignore next */
function removeToken() {
  /* istanbul ignore next */
  Storage.remove(TOKEN_KEY);
}

/* istanbul ignore next */

export { getToken, parseJWT, setToken, removeToken };
//# sourceMappingURL=boldr-auth.browser.es5.esm.js.map
